# Parsec Cloud (https://parsec.cloud) Copyright (c) AGPL-3.0 2016-present Scille SAS
from __future__ import annotations

from parsec.core.fs.exceptions import (
    # Remote operation errors
    FSBackendOfflineError,
    FSBadEncryptionRevision,
    FSCrossDeviceError,
    FSDeviceNotFoundError,
    FSDirectoryNotEmptyError,
    FSEndOfFileError,
    # Generic classes
    FSError,
    FSFileExistsError,
    FSFileNotFoundError,
    FSInvalidArgumentError,
    FSInvalidFileDescriptor,
    FSInvalidTrustchainError,
    FSIsADirectoryError,
    FSLocalOperationError,
    FSNameTooLongError,
    FSNoAccessError,
    FSNotADirectoryError,
    FSOperationError,
    # Local operation errors
    FSPermissionError,
    FSReadOnlyError,
    FSRemoteBlockNotFound,
    FSRemoteManifestNotFound,
    FSRemoteManifestNotFoundBadVersion,
    FSRemoteOperationError,
    FSRemoteSyncError,
    FSSharingNotAllowedError,
    FSUserNotFoundError,
    FSWorkspaceArchivingNotAllowedError,
    FSWorkspaceArchivingPeriodTooShort,
    FSWorkspaceInMaintenance,
    FSWorkspaceNoAccess,
    FSWorkspaceNoReadAccess,
    # Misc errors
    FSWorkspaceNotFoundError,
    FSWorkspaceNotInMaintenance,
    FSWorkspaceNoWriteAccess,
    FSWorkspaceRealmArchived,
    FSWorkspaceRealmDeleted,
    FSWorkspaceTimestampedTooEarly,
)
from parsec.core.fs.path import AnyPath, FsPath
from parsec.core.fs.userfs import UserFS
from parsec.core.fs.workspacefs import (
    ChangesAfterSync,
    RemanenceManagerInfo,
    WorkspaceFS,
    WorkspaceFSTimestamped,
)

__all__ = (
    "UserFS",
    "WorkspaceFS",
    "WorkspaceFSTimestamped",
    "ChangesAfterSync",
    "RemanenceManagerInfo",
    # Path
    "FsPath",
    "AnyPath",
    # Generic error classes
    "FSError",
    "FSOperationError",
    "FSLocalOperationError",
    "FSRemoteOperationError",
    # Misc errors
    "FSWorkspaceNotFoundError",
    "FSWorkspaceTimestampedTooEarly",
    # Local operation errors
    "FSPermissionError",
    "FSNoAccessError",
    "FSReadOnlyError",
    "FSNotADirectoryError",
    "FSFileNotFoundError",
    "FSCrossDeviceError",
    "FSFileExistsError",
    "FSIsADirectoryError",
    "FSDirectoryNotEmptyError",
    "FSInvalidFileDescriptor",
    "FSInvalidArgumentError",
    "FSEndOfFileError",
    "FSNameTooLongError",
    # Remote operation error
    "FSBackendOfflineError",
    "FSRemoteManifestNotFound",
    "FSRemoteManifestNotFoundBadVersion",
    "FSRemoteBlockNotFound",
    "FSRemoteSyncError",
    "FSBadEncryptionRevision",
    "FSSharingNotAllowedError",
    "FSWorkspaceNoAccess",
    "FSWorkspaceNoReadAccess",
    "FSWorkspaceNoWriteAccess",
    "FSWorkspaceNotInMaintenance",
    "FSWorkspaceInMaintenance",
    "FSWorkspaceRealmArchived",
    "FSWorkspaceRealmDeleted",
    "FSUserNotFoundError",
    "FSDeviceNotFoundError",
    "FSInvalidTrustchainError",
    "FSWorkspaceArchivingNotAllowedError",
    "FSWorkspaceArchivingPeriodTooShort",
)
